@@ -1,12 +1,24 @@
+//! # `/coins`
+//!
+//! - [/coins/list](List) 
+//! - [/coins/markets](Markets)
+//! - [/coins/{id}](Info)
+//! - [/coins/{id}/tickers](Tickers)
+//! - [/coins/{id}/history](History)
+//! - [/coins/{id}/market_chart](MarketChart)
+//! - [/coins/{id}/market_chart_range](MarketChartRange)
+//! - [/coins/{id}/status_updates](StatusUpdates)
+//! - [/coins/{id}/ohlc](OHLC)
 use crate::Route;
 
+
 pub struct List {
-    endpoint: String,           // /coins/list
+    endpoint: String,
     pub include_platform: bool, // default not specified in docs assume False
 }
 pub struct Markets {
-    endpoint: String,        // /coins/markets
-    pub vs_currency: String, // required
+    endpoint: String,
+    pub vs_currency: String,
     pub ids: String,
     pub category: String,
     pub order: String, // valid calues: market_cap_desc, gecko_desc, gecko_asc, market_cap_asc, market_cap_desc, volume_asc, volume_desc, id_asc, id_desc
@@ -17,7 +29,7 @@ pub struct Markets {
     // valid format: '1h' , '14d', '1y', multi values comma separated
 }
 pub struct Info {
-    endpoint: String, // /coins/{id}
+    endpoint: String,
     pub id: String,
     pub localization: bool,   // true
     pub tickers: bool,        // true
@@ -27,7 +39,7 @@ pub struct Info {
     pub sparkline: bool,      // false
 }
 pub struct Tickers {
-    endpoint: String, // /coins/{id}/tickers
+    endpoint: String,
     pub id: String,
     pub exchange_ids: String,
     pub include_exchange_logo: bool,
@@ -36,33 +48,33 @@ pub struct Tickers {
     pub depth: bool,
 }
 pub struct History {
-    endpoint: String, // /coins/{id}/history
+    endpoint: String,
     pub id: String,
     pub date: String,       // dd-mm-yyyy format
     pub localization: bool, // set to false to exlude localized languages in reponse ---- maybe just a bool or
 }
 pub struct MarketChart {
-    endpoint: String, // /coins/{id}/market_chart
+    endpoint: String,
     pub id: String,
     pub vs_currency: String,
     pub days: String, // data up to days ago 1,14,30,max
     pub interval: String,
 }
 pub struct MarketChartRange {
-    endpoint: String, // /coins/{id}/market_chart/range
+    endpoint: String,
     pub id: String,
     pub vs_currency: String,
     pub from: i64,
     pub to: i64, // unix timestamp
 }
 pub struct StatusUpdates {
-    endpoint: String, // /coins/{id}/status_updates
+    endpoint: String,
     pub id: String,
     pub per_page: i32,
     pub page: i32,
 }
 pub struct OHLC {
-    endpoint: String, // /coins/{id}/ohlc
+    endpoint: String,
     pub id: String,
     pub vs_currency: String,
     pub days: String, // 1/7/14/30/max --  only success is 1 and max
