@@ -1,19 +1,25 @@
+//! # `/contract`
+//!
+//! - [/coins/{id}/contract/{contract_address}](Info)
+//! - [/coins/{id}/contract/{contract_address}/market_chart](MarketChart)
+//! - [/coins/{id}/contract/{contract_address}/market_chart/range](MarketChartRange)
+//!
 use crate::Route;
 
 pub struct Info {
-    endpoint: String, // /coins/{id}/contract/{contract_address}
+    endpoint: String,
     pub id: String,
     pub contract_address: String,
 }
 pub struct MarketChart {
-    endpoint: String, // /coins/{id}/contract/{contract_address}/market_chart
+    endpoint: String,
     pub id: String,
     pub contract_address: String,
     pub vs_currency: String,
     pub days: String,
 }
 pub struct MarketChartRange {
-    endpoint: String, // /coins/{id}/contract/{contract_address}/market_chart/range
+    endpoint: String,
     pub id: String,
     pub contract_address: String,
     pub vs_currency: String,
