@@ -1,17 +1,23 @@
+//! # `/indexes`
+//!
+//! - [/indexes](Indexes)
+//! - [/indexes/{market_id}/{id}](Info)
+//! - [/indexes/list](List)
+//!
 use crate::Route;
 
 pub struct Indexes {
-    endpoint: String, // /indexes
+    endpoint: String,
     pub per_page: i32,
     pub page: i32,
 }
 pub struct Info {
-    endpoint: String, // /indexes/{market_id}/{id}
+    endpoint: String,
     pub id: String,
     pub market_id: String,
 }
 pub struct List {
-    endpoint: String, // /indexes/list
+    endpoint: String,
 }
 
 impl Indexes {
