@@ -1,3 +1,9 @@
+//! # `/simple`
+//!
+//! - [/simple/price](Price)
+//! - [/simple/token_price/{id}](TokenPrice)
+//! - [/simple/supported_vs_currencies](SupportedCurrency)
+//!
 use crate::Route;
 
 #[derive(Debug)]
@@ -13,13 +19,13 @@ pub struct Price {
 #[derive(Debug)]
 pub struct TokenPrice {
     endpoint: String,
-    pub id: String,                    // path
-    pub contract_addresses: String,    // query
-    pub vs_currencies: String,         // query
-    pub include_market_cap: bool,      // query false
-    pub include_24hr_vol: bool,        // query fasle
-    pub include_24hr_change: bool,     // query false
-    pub include_last_updated_at: bool, // query false
+    pub id: String,
+    pub contract_addresses: String,
+    pub vs_currencies: String,
+    pub include_market_cap: bool,
+    pub include_24hr_vol: bool,
+    pub include_24hr_change: bool,
+    pub include_last_updated_at: bool,
 }
 #[derive(Debug)]
 pub struct SupportedCurrency {
