@@ -1,7 +1,11 @@
+//! # `/status_updates`
+//!
+//! - [/status_updates](StatusUpdates)
+//!
 use crate::Route;
 
 pub struct StatusUpdates {
-    endpoint: String, // /status_updates
+    endpoint: String,
     pub category: String,
     pub project_type: String,
     pub per_page: i32,
