@@ -1,7 +1,10 @@
+//! # `/trending`
+//! 
+//! - [/trending](Trending)
 use crate::Route;
 
 pub struct Trending {
-    endpoint: String, // /search/trending
+    endpoint: String,
 }
 
 impl Trending {
