@@ -34,7 +34,7 @@ async fn test_status_updates() {
 }
 
 #[tokio::test]
-async fn test_volume_data() {
-    let resource = exchanges::VolumeData::required(ID.to_string(), "14".to_string());
+async fn test_volume_chart() {
+    let resource = exchanges::VolumeChart::required(ID.to_string(), "14".to_string());
     generic::test_get(&resource).await;
 }
